import { colorLegend } from './colorLegend';

const colorScale = d3.scaleOrdinal()
  .domain(['Travel Hubei', 'Relative', 'Social', 'Public Transit'])
  .range([
    '#5c2ea8',
    '#1199ff',
    '#00b7a3',
    '#fa9fb5'
  ]);

// set the dimensions and margins of the graph
var margin = {top: 50, right: 30, bottom: 60, left: 120},
    width = 860 - margin.left - margin.right,
    height = 500 - margin.top - margin.bottom;

// append the svg object to the body of the page
var svg = d3.select("svg")
    .attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
  .append("g")
    .attr("transform",
          "translate(" + margin.left + "," + margin.top + ")");

const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const colorLegendG = svg.append('g')
    .attr('transform',`translate(620,20)`);

//Read the data
d3.csv("data3.csv", function(data) {

  console.log(data);
  data.forEach(d => {
  	d.year = new Date(d.year);
    d.n = +d.n;
  });
  
  // group the data: I want to draw one line per group
  var sumstat = d3.nest() // nest function allows to group the calculation per level of a factor
    .key(function(d) { return d.name;})
    .entries(data);

  // Add X axis --> it is a date format
  const x = d3.scaleTime()
  		.domain(d3.extent(data, function(d) { return d.year;}))
  		.range([0, innerWidth])
  		.nice();
  const xAxis = d3.axisBottom(x)
  							// .tickFormat(xAxisTickFormat)
  							.tickSize(0)
  							.tickPadding(10);
  
  const xAxisG = svg.append('g')
  	.attr('class', 'axis')
  	.call(xAxis)
  	.attr('transform', 'translate(0,'+height+')');
  
  //var x = d3.scaleLinear()
 //   .domain(d3.extent(data, function(d) { return d.year; }))
 //   .range([ 0, width ]);
 // svg.append("g")
 //   .attr("transform", "translate(0," + height + ")")
 //   .call(d3.axisBottom(xScale).ticks(5));

  // Add Y axis
  var y = d3.scaleLinear()
    .domain([0, d3.max(data, function(d) { return +d.n; })])
    .range([ height, 0 ]);
  svg.append("g")
  	.attr('class', 'axis')
    .call(d3.axisLeft(y));

  // color palette
  var res = sumstat.map(function(d){ return d.key }) // list of group names
  var color = d3.scaleOrdinal()
    .domain(res)
    .range(['#e41a1c','#377eb8','#4daf4a','#984ea3','#ff7f00','#ffff33','#a65628','#f781bf','#999999']);

  // Draw the line
  svg.selectAll(".line")
      .data(sumstat)
      .enter()
      .append("path")
  			.attr('class', 'line-path')
        .attr("stroke", function(d){ return colorScale(d.key) })
        .attr("d", function(d){
          return d3.line()
            .x(function(d) { return x(d.year); })
            .y(function(d) { return y(+d.n); })
            (d.values)
        });
  
  colorLegendG.call(colorLegend,{
      colorScale,
      circleRadius: 10,
      spacing: 25,
      textOffset: 20
  });

})